@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Exporter::Tiny;
+use Exporter 'import';
 
 our @EXPORT    = qw/return_modifiers/;
 our @EXPORT_OK = qw/return_modifiers return_has return_with return_around return_extends return_before return_after/;
@@ -55,7 +55,7 @@ MooX::ReturnModifiers - Returns Moo Modifiers as a Hash
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
